diff --git a/ChangeLog b/ChangeLog index 062f5cb404..5ee8714d13 100644 --- a/ChangeLog +++ b/ChangeLog @@ -20,9 +20,10 @@ phpMyAdmin - ChangeLog - bug #3941 Recent tables list always empty - bug #3933 Do not translate "Open Document" in export settings - bug #3927 List of tables is missing after expanding in the navigation frame -- bug #3942 Warnings about reserved word for many non reserved words +- bug #3942 Warnings about reserved word for many non reserved words +- bug #3912 Exporting row selection, resulted by ORDER BY query -4.0.2.0 (not yet released) +4.0.2.0 (2013-05-24) - bug #3902 Cannot browse when table name contains keyword "call" + center loading indicator for navigation refresh, related to bug #3920 - bug #3925 Table sorting in navigation panel is case-sensitive diff --git a/js/ajax.js b/js/ajax.js index 3c13151975..f43a2d0977 100644 --- a/js/ajax.js +++ b/js/ajax.js @@ -136,7 +136,7 @@ var AJAX = { return true; } else if (href && href.match(/^mailto/)) { return true; - } else if ($(this).hasClass('ui-datepicker-next') || + } else if ($(this).hasClass('ui-datepicker-next') || $(this).hasClass('ui-datepicker-prev') ) { return true; @@ -255,6 +255,7 @@ var AJAX = { $('#page_content').replaceWith( "
';
- $output .= PMA_SQP_formatHtml(PMA_SQP_parse(implode($queries)));
+ $output .= PMA_SQP_format(
+ PMA_SQP_parse(implode($queries)),
+ 'text'
+ );
$output .= '';
// Display results
diff --git a/libraries/sql.lib.php b/libraries/sql.lib.php
index 1b73959fff..2055c49bba 100644
--- a/libraries/sql.lib.php
+++ b/libraries/sql.lib.php
@@ -593,9 +593,8 @@ EOT;
$profiling_table .= '';
$profiling_table .= '';
$profiling_table .= '' . "\n";
diff --git a/po/af.po b/po/af.po
index c80b942bc7..e4843822f2 100644
--- a/po/af.po
+++ b/po/af.po
@@ -3,7 +3,7 @@ msgid ""
msgstr ""
"Project-Id-Version: phpMyAdmin 4.1-dev\n"
"Report-Msgid-Bugs-To: phpmyadmin-devel@lists.sourceforge.net\n"
-"POT-Creation-Date: 2013-05-24 09:03-0400\n"
+"POT-Creation-Date: 2013-05-25 07:32-0400\n"
"PO-Revision-Date: 2013-02-13 18:58+0200\n"
"Last-Translator: Andrey Prokopenko
diff --git a/libraries/sqlparser.lib.php b/libraries/sqlparser.lib.php
index effbe0ea15..5bdc8d096a 100644
--- a/libraries/sqlparser.lib.php
+++ b/libraries/sqlparser.lib.php
@@ -19,7 +19,7 @@
* from the analyzer.
*
* If you want a pretty-printed version of the query, do:
- * $string = PMA_SQP_formatHtml($parsed_sql);
+ * $string = PMA_SQP_format($parsed_sql);
* (note that that you need to have syntax.css.php included somehow in your
* page for it to work, I recommend '' at the moment.)
@@ -2174,10 +2174,10 @@ function PMA_SQP_formatHtml_colorize($arr)
/**
- * Formats SQL queries to html
+ * Formats SQL queries
*
* @param array $arr The SQL queries
- * @param string $mode mode of printing
+ * @param string $mode formatting mode
* @param integer $start_token starting token
* @param integer $number_of_tokens number of tokens to format, -1 = all
*
@@ -2185,7 +2185,7 @@ function PMA_SQP_formatHtml_colorize($arr)
*
* @access public
*/
-function PMA_SQP_formatHtml(
+function PMA_SQP_format(
$arr, $mode='color', $start_token=0,
$number_of_tokens=-1
) {
@@ -2888,7 +2888,7 @@ function PMA_SQP_formatHtml(
*/
$str .= $before;
if ($mode=='color') {
- $str .= PMA_SQP_formatHTML_colorize($arr[$i]);
+ $str .= PMA_SQP_formatHtml_colorize($arr[$i]);
} elseif ($mode == 'text') {
$str .= htmlspecialchars($arr[$i]['data']);
} else {
@@ -2916,7 +2916,7 @@ function PMA_SQP_formatHtml(
}
return $str;
-} // end of the "PMA_SQP_formatHtml()" function
+} // end of the "PMA_SQP_format()" function
/**
* Gets SQL queries with no format